aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/qpdf/QUtil.hh6
1 files changed, 5 insertions, 1 deletions
diff --git a/include/qpdf/QUtil.hh b/include/qpdf/QUtil.hh
index f5ff3323..a70db0bd 100644
--- a/include/qpdf/QUtil.hh
+++ b/include/qpdf/QUtil.hh
@@ -32,8 +32,12 @@ namespace QUtil
char* copy_string(std::string const&);
// Set stdout to binary mode
void binary_stdout();
+ void binary_stdin();
+
+ // May modify argv0
+ char* getWhoami(char* argv0);
// Get the value of an environment variable in a portable fashion.
// Returns true iff the variable is defined. If `value' is
@@ -32,8 +32,12 @@ namespace QUtil
char* copy_string(std::string const&);
- // Set stdout to binary mode
+ // Set stdin, stdout to binary mode
void binary_stdout();